@@ -1,17 +1,18 @@
-# -*- coding: cp1252 -*-
+# -*- coding: ascii -*-
+from os import path
 
-__VERSION__ = "0.7.3"
+__VERSION__ = open(path.join(path.dirname(__file__), 'version.txt')).read().strip()
 
-# <p>Copyright  2005-2012 Stephen John Machin, Lingfo Pty Ltd</p>
+# <p>Copyright (c) 2005-2012 Stephen John Machin, Lingfo Pty Ltd</p>
 # <p>This module is part of the xlrd package, which is released under a
 # BSD-style licence.</p>
 
 import licences
 
 ##
-# <p><b>A Python module for extracting data from MS Excel  spreadsheet files.
+# <p><b>A Python module for extracting data from MS Excel (TM) spreadsheet files.
 # <br /><br />
-# Version 0.7.3 -- February/March 2012
+# Version 0.7.4 -- April 2012
 # </b></p>
 #
 # <h2>General information</h2>
@@ -745,7 +746,8 @@ class Book(BaseObject):
     # <i>built_in</i> 1 = built-in style, 0 = user-defined<br />
     # <i>xf_index</i> is an index into Book.xf_list.<br />
     # References: OOo docs s6.99 (STYLE record); Excel UI Format/Style
-    # <br /> -- New in version 0.6.1
+    # <br /> -- New in version 0.6.1; since 0.7.4, extracted only if
+    # open_workbook(..., formatting_info=True)
     style_name_map = {}
 
     ##
